@@ -6,6 +6,7 @@ Created on Fri Oct 11 14:55:20 2019
 """
 import numpy as np
 import warnings
+from scipy.stats import rv_continuous
 
 def bic(log_like, n, k):
 
@@ -211,3 +212,63 @@ def r_squared(obs, calc):
     """      
   
     return 1 - (np.sum(np.square(obs-calc)) / np.sum(np.square(obs-np.mean(obs))) )
+
+
+
+
+class MixtureModel(rv_continuous):
+
+    def __init__(self, submodels, *args, weights = None, **kwargs):
+        """
+        create a distribution composed of a number of scipy.stats distribitions
+        #copied from https://stackoverflow.com/questions/47759577/creating-a-mixture-of-probability-distributions-for-sampling
+        
+        Parameters
+        ----------
+        submodels : scipy frozen
+            scipy frozen distribution e.g. norm, uniform,...
+        weights : list of floats
+            weight of each distribution, by default None
+
+        Examples
+        -------
+        >>> mixture_gaussian_model = MixtureModel([uniform(-3, 3), norm(3, 1)]) #weights = [0.3, 0.5, 0.2]
+        >>> x_axis = np.arange(-6, 6, 0.001)
+        >>> mixture_pdf = mixture_gaussian_model.pdf(x_axis)
+        >>> mixture_rvs = mixture_gaussian_model.rvs(100000)
+
+        """
+
+        super().__init__(*args, **kwargs)
+        self.submodels = submodels
+        if weights is None:
+            weights = [1 for _ in submodels]
+        if len(weights) != len(submodels):
+            raise(ValueError(f'There are {len(submodels)} submodels and {len(weights)} weights, but they must be equal.'))
+        self.weights = [w / sum(weights) for w in weights]
+        
+    def _pdf(self, x):
+        pdf = self.submodels[0].pdf(x) * self.weights[0]
+        for submodel, weight in zip(self.submodels[1:], self.weights[1:]):
+            pdf += submodel.pdf(x)  * weight
+        return pdf
+            
+    def _sf(self, x):
+        sf = self.submodels[0].sf(x) * self.weights[0]
+        for submodel, weight in zip(self.submodels[1:], self.weights[1:]):
+            sf += submodel.sf(x)  * weight
+        return sf
+
+    def _cdf(self, x):
+        cdf = self.submodels[0].cdf(x) * self.weights[0]
+        for submodel, weight in zip(self.submodels[1:], self.weights[1:]):
+            cdf += submodel.cdf(x)  * weight
+        return cdf
+
+    
+
+    def rvs(self, size):
+        submodel_choices = np.random.choice(len(self.submodels), size=size, p = self.weights)
+        submodel_samples = [submodel.rvs(size=size) for submodel in self.submodels]
+        rvs = np.choose(submodel_choices, submodel_samples)
+        return rvs
